aboutsummaryrefslogtreecommitdiffstats
path: root/packet-ospf.h
diff options
context:
space:
mode:
authorhannes <hannes@f5534014-38df-0310-8fa8-9805f1628bb7>1998-09-29 21:32:46 +0000
committerhannes <hannes@f5534014-38df-0310-8fa8-9805f1628bb7>1998-09-29 21:32:46 +0000
commite3c45fd3eac1a278594c9ab5e4d9551c18b61318 (patch)
treec634ad068e031fecbfbb0cd92bad077b4e2385fa /packet-ospf.h
parent214a634bcfe889e619b41634937ce756759baead (diff)
structure for AS-external LSA added.
documentation line changed. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@32 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'packet-ospf.h')
-rw-r--r--packet-ospf.h10
1 files changed, 9 insertions, 1 deletions
diff --git a/packet-ospf.h b/packet-ospf.h
index 8e3b6af377..fec845cd66 100644
--- a/packet-ospf.h
+++ b/packet-ospf.h
@@ -114,6 +114,14 @@ typedef struct _e_ospf_summary_lsa {
guint32 network_mask;
} e_ospf_summary_lsa;
+typedef struct _e_ospf_asexternal_lsa {
+ guint8 options;
+ guint8 metric[3];
+ guint32 gateway;
+ guint32 external_tag;
+} e_ospf_asexternal_lsa;
+
+
void dissect_ospf_hello(const u_char*, int, frame_data*, GtkTree*);
void dissect_ospf_db_desc(const u_char*, int, frame_data*, GtkTree*);
void dissect_ospf_ls_req(const u_char*, int, frame_data*, GtkTree*);
@@ -122,6 +130,6 @@ void dissect_ospf_ls_ack(const u_char*, int, frame_data*, GtkTree*);
/* dissect_ospf_lsa returns the length of the LSA
* if disassemble_body is set to FALSE (e.g. in LSA ACK
* packets), the header length is returned
*/
int dissect_ospf_lsa(const u_char*, int, frame_data*, GtkTree*, int disassemble_body);
@@ -122,6 +130,6 @@ void dissect_ospf_ls_ack(const u_char*, int, frame_data*, GtkTree*);
/* dissect_ospf_lsa returns the length of the LSA
* if disassemble_body is set to FALSE (e.g. in LSA ACK
- * packets), the header length is returned
+ * packets), the LSA-header length is returned (20)
*/
int dissect_ospf_lsa(const u_char*, int, frame_data*, GtkTree*, int disassemble_body);